@@ -70,7 +70,7 @@ void MainWindow::itemActivated(QListWidgetItem* item)
     int idx = item->data(Qt::UserRole).toInt();
     const RedditEntry& e = m_ses->getEntries()[idx];
 
-    qDebug() << "use ent " << e.permalink;
+    //qDebug() << "use ent " << e.permalink;
 
     m_com->setEntry(e);
     m_com->show();
